@@ -1,32 +1,24 @@
-##' Short summary of the random effects parameters, the fixed treatment 
-##' effects, and the surrogacy evaluation criteria estimated from a joint surrogate model
+##' Short summary of the surrogacy evaluation criteria estimated from a joint surrogate model
 ##' 
-##' This function returns the estimate of the coefficients and their standard error with p-values 
-##' of the Wald test for the joint surrogate model, also hazard ratios (HR) and their 
-##' confidence intervals for the fixed treatment effects, and finaly an estimate of the 
-##' surrogacy evaluation criterian (Kendall's \eqn{\tau} and \if{latex}{\eqn{R^2_{trial}}}
-#'    \if{html}{\code{R}\out{<sup>2</sup><sub>trial</sub>}})
+##' This function returns the estimate of the coefficient, the hazard ratios (HR) and their 
+##' confidence intervals for the fixed treatment effects. Also, an estimate of the 
+##' surrogacy evaluation criteria (Kendall's \eqn{\tau}, \if{latex}{\eqn{R^2_{trial}}}
+#'    \if{html}{\code{R}\out{<sup>2</sup><sub>trial</sub>}} and STE)
 ##' 
 ##' 
-##' @aliases summary.jointSurroPenal print.summary.jointSurroPenal
-##' @usage \method{summary}{jointSurroPenal}(object, d = 4, len = 3, int.method.kt = 0, 
-##' nb.gh = 32, ...)
+##' @aliases summary.jointSurroPenal
+##' @usage \method{summary}{jointSurroPenal}(object, d = 4, len = 3, nb.gh = 32, ...)
 ##' 
 ##' @param object An object inheriting from \code{jointSurroPenal} class.
 ##' @param d The desired number of digits after the decimal point for parameters. 
 ##' The maximum of 4 digits is required for the estimates. Default of 3 digits is used.
 ##' @param len The desired number of digits after the decimal point for p-value and convergence 
 ##' criteria. Default of 4 digits is used.
-##' @param int.method.kt A binary, indicates the integration method for Kendall's \eqn{\tau}
-##' estimation : \code{0} for Monte carlo, and \code{1} for Gaussian Hermite quadrature. 
-##' the default is \code{0}. 
 ##' @param  nb.gh Number of nodes for the Gaussian-Hermite quadrature.  The default is \code{32}
 ##' \code{1} for Gaussian-Hermite quadrature.
 ##' @param \dots other unused arguments.
 ##' 
-##' @return For the variances parameters of the random effects, it prints the estimate of
-##' the coefficients with their standard error, Z-statistics and p-values
-##' of the Wald test. For the fixed treatment effects, it also prints HR and its confidence
+##' @return For the fixed treatment effects, it also prints HR and its confidence
 ##' intervals for each covariate. For the surrogacy evaluation criteria, its prints the estimated 
 ##' Kendall's \eqn{\tau} with its 95\% Confidence interval obtained by the parametric bootstrap
 ##'  or Delta-method, 
@@ -41,9 +33,7 @@
 ##' the suggestion of the Institute of Quality and Efficiency in Health Care 
 ##' (Prasad \emph{et al.}, 2015). 
 ##' We also display the surrogate threshold effect (\code{\link[=ste]{ste}}) with the associated hazard risk.
-##' The rest of parameters concerns the convergence characteristics and 
-##' included: the penalized marginal log-likelihood, the number of iterations, the LCV and the Convergence criteria.
-##' @seealso \code{\link{jointSurroPenal}, \link{jointSurroCopPenal}, \link{jointSurroTKendall}}
+##' @seealso \code{\link{jointSurroPenal}, \link{jointSurroCopPenal}, \link{jointSurroTKendall}, \link{print.jointSurroPenal}}
 ##' 
 ##' @author Casimir Ledoux Sofeu \email{casimir.sofeu@u-bordeaux.fr}, \email{scl.ledoux@gmail.com} and 
 ##' Virginie Rondeau \email{virginie.rondeau@inserm.fr}
@@ -75,13 +65,13 @@
 ##'                    nb.gh = 20, indicator.alpha = 1, n.knots = 6)
 ##'                             
 ##' summary(joint.surrogate)
-##' summary(joint.surrogate, d = 4, len = 3, int.method.kt = 1, nb.gh = 25)
 ##' }
 ##' 
 ##' 
 "summary.jointSurroPenal"<-
-  function(object, d = 4, len = 3, int.method.kt = 0, nb.gh = 32, ...){
+  function(object, d = 4, len = 3, nb.gh = 32, ...){
     x <- object
+    int.method.kt = 0
     if (!inherits(x, "jointSurroPenal"))
       stop("Object must be of class 'jointSurroPenal'")
     
@@ -102,16 +92,16 @@
     p <- ifelse(as.numeric(beta$P) < 10^-10, "< e-10", beta$P)
     beta$P <- p
     
-    cat("Estimates for variances parameters of the random effects", "\n")
+    # cat("Estimates for variances parameters of the random effects", "\n")
     rownames(beta)[(nrow(beta) - 4)] <- "sigma2_S"
     rownames(beta)[(nrow(beta) - 3)] <- "sigma2_T"
     rownames(beta)[(nrow(beta) - 2)] <- "sigma_ST"
-    print(beta[1:(nrow(beta) - 2),])
+    # print(beta[1:(nrow(beta) - 2),])
     
     beta2 <- beta[((nrow(beta) - 1) : nrow(beta)),]
     beta2$Estimate <- round(beta2$Estimate,min(4,len))
    
-    cat(" ", "\n")
+    # cat(" ", "\n")
     cat("Estimates for the fixed treatment effects", "\n")
     print(beta2)
     
@@ -147,11 +137,12 @@
     validation[,4] <- round(validation[,4], len)
     validation[2,2] <- as.character(round(as.numeric(validation[2,2]), len))
     if(int.method.kt == 1){
-      validation[1,1] <- jointSurroTKendall(theta = object$Coefficients["Theta",1],
-                                            gamma = ifelse(is.na(object$Coefficients["gamma",1]), 0, object$Coefficients["gamma",1]),
-                                            alpha = ifelse(is.na(object$Coefficients["alpha",1]), 1, object$Coefficients["alpha",1]),
-                                            zeta = ifelse(is.na(object$Coefficients["zeta",1]), 1, object$Coefficients["zeta",1]),
-                                            nb.gh, ui = ifelse(is.na(object$Coefficients["gamma",1]), 0, 1))
+      validation[1,1] <- jointSurroTKendall(object = object, int.method = 1)
+      # validation[1,1] <- jointSurroTKendall(theta = object$Coefficients["theta",1],
+      #                                       gamma = ifelse(is.na(object$Coefficients["gamma",1]), 0, object$Coefficients["gamma",1]),
+      #                                       alpha = ifelse(is.na(object$Coefficients["alpha",1]), 1, object$Coefficients["alpha",1]),
+      #                                       zeta = ifelse(is.na(object$Coefficients["zeta",1]), 1, object$Coefficients["zeta",1]),
+      #                                       nb.gh = nb.gh, ui = ifelse(is.na(object$Coefficients["gamma",1]), 0, 1), int.method = 1)
     }
     
     names(validation)[2] <- "Std Error"
@@ -175,16 +166,29 @@
     cat("Correlation strength: <= 0.49 'Low'; ]0.49 - 0.72[ 'Medium'; >= 0.72 'High' ","\n")
     cat("---","\n")
     
-    cat(c("Surrogate threshold effect (STE) :",round(ste(object),len),"(HR =",round(exp(ste(object)),len),")"),"\n")
+    STE = ste(object)
+    if(length(STE) == 0){
+      cat(c("Surrogate threshold effect (STE) : --"),"\n")
+    }
     
-    cat(" ", "\n")
-    cat("Convergence parameters", "\n")
-    cat(c("Penalized marginal log-likelihood = ", round(object$loglikPenal, len)), "\n")
-    cat(c("Number of iterations = ", object$n.iter),"\n")
-    cat("LCV = the approximate likelihood cross-validation criterion", "\n")
-    cat(c("      in the semi parametrical case     = ", round(object$LCV, len)),"\n")
-    cat("Convergence criteria:", "\n")
-    EPS <- formatC(object$EPS, d, format = "g")
-    cat(c("  parameters = ",EPS[1], "likelihood = ", EPS[2], "gradient = ", EPS[3]), "\n")
+    if(length(STE) == 1){
+      cat(c("Surrogate threshold effect (STE) :",round(STE,len),"(HR =",round(exp(STE),len),")"),"\n")
+    }
+    
+    if(length(STE) == 2){
+      cat(c("Surrogate threshold effect (STE) : (",round(STE[1],len), ",", round(STE[2],len),"); HR = (",round(exp(STE[1]),len), ",", round(exp(STE[2]),len),")"),"\n")
+    }
+    
+    # cat(" ", "\n")
+    # cat("Convergence parameters", "\n")
+    # cat(c("Penalized marginal log-likelihood = ", round(object$loglikPenal, len)), "\n")
+    # cat(c("Number of iterations = ", object$n.iter),"\n")
+    # cat(c("Smoothing parameters = ", object$kappa),"\n")
+    # cat(c("Number of spline nodes = ", object$parameter["n.knots"]),"\n")
+    # cat("LCV = the approximate likelihood cross-validation criterion", "\n")
+    # cat(c("      in the semi parametrical case     = ", round(object$LCV, len)),"\n")
+    # cat("Convergence criteria:", "\n")
+    # EPS <- formatC(object$EPS, d, format = "g")
+    # cat(c("  parameters = ",EPS[1], "likelihood = ", EPS[2], "gradient = ", EPS[3]), "\n")
   }
 
